@@ -1,4 +1,3 @@
-/* $Xorg: register.c,v 1.4 2001/02/09 02:03:26 xorgcvs Exp $ */
 /******************************************************************************
 
 
@@ -34,19 +33,17 @@ Author: Ralph Mor, X Consortium
 #include "ICElibint.h"
 
 int
-IceRegisterForProtocolSetup (protocolName, vendor, release,
-    versionCount, versionRecs, authCount, authNames, authProcs, IOErrorProc)
-
-char			*protocolName;
-char			*vendor;
-char			*release;
-int			versionCount;
-IcePoVersionRec		*versionRecs;
-int			authCount;
-char		        **authNames;
-IcePoAuthProc		*authProcs;
-IceIOErrorProc		IOErrorProc;
-
+IceRegisterForProtocolSetup (
+	const char		*protocolName,
+	const char		*vendor,
+	const char		*release,
+	int			versionCount,
+	IcePoVersionRec		*versionRecs,
+	int			authCount,
+	const char	        **authNames,
+	IcePoAuthProc		*authProcs,
+	IceIOErrorProc		IOErrorProc
+)
 {
     _IcePoProtocol 	*p;
     int			opcodeRet, i;
@@ -59,7 +56,7 @@ IceIOErrorProc		IOErrorProc;
 		/*
 		 * We've already registered this protocol.
 		 */
-		
+
 		return (i);
 	    }
 	    else
@@ -67,7 +64,7 @@ IceIOErrorProc		IOErrorProc;
 		break;
 	    }
 	}
-	    
+
     if (i <= _IceLastMajorOpcode)
     {
 	p = _IceProtocols[i - 1].orig_client =
@@ -133,24 +130,20 @@ IceIOErrorProc		IOErrorProc;
 
 
 int
-IceRegisterForProtocolReply (protocolName, vendor, release,
-    versionCount, versionRecs, authCount, authNames, authProcs,
-    hostBasedAuthProc, protocolSetupProc, protocolActivateProc,
-    IOErrorProc)
-
-char				*protocolName;
-char				*vendor;
-char				*release;
-int				versionCount;
-IcePaVersionRec			*versionRecs;
-int				authCount;
-char				**authNames;
-IcePaAuthProc			*authProcs;
-IceHostBasedAuthProc		hostBasedAuthProc;
-IceProtocolSetupProc		protocolSetupProc;
-IceProtocolActivateProc		protocolActivateProc;
-IceIOErrorProc			IOErrorProc;
-
+IceRegisterForProtocolReply (
+	const char			*protocolName,
+	const char			*vendor,
+	const char			*release,
+	int				versionCount,
+	IcePaVersionRec			*versionRecs,
+	int				authCount,
+	const char			**authNames,
+	IcePaAuthProc			*authProcs,
+	IceHostBasedAuthProc		hostBasedAuthProc,
+	IceProtocolSetupProc		protocolSetupProc,
+	IceProtocolActivateProc		protocolActivateProc,
+	IceIOErrorProc			IOErrorProc
+)
 {
     _IcePaProtocol 	*p;
     int			opcodeRet, i;
@@ -163,7 +156,7 @@ IceIOErrorProc			IOErrorProc;
 		/*
 		 * We've already registered this protocol.
 		 */
-		
+
 		return (i);
 	    }
 	    else
@@ -171,7 +164,7 @@ IceIOErrorProc			IOErrorProc;
 		break;
 	    }
 	}
-	    
+
 
     if (i <= _IceLastMajorOpcode)
     {
